/*
------------------------------Copyright----------------------------
 SuperMap iDesktop 8C sample code
 Copyright: SuperMap Software Co., Ltd.
------------------------------------------------------------------

-----------------------------SuperMap iDesktop 8C Sample Description---------------------------

1. Introduction: How to start work automatically by plugin after starting the Desktop.
2. Scene: 3D flying after starting the program
3. Data: Workspace (SampleData/3D/CBDDataset/CBD.sxwu); Scene (CBD)       
4. Key files, types and members:
      Plugin.config Configuration file
      FormBase.LoadedUI Event
      Application.Workspace Property
      Application.CreateSceneWindow Method
      IFormMain.FullScreen Property
      Other component interfaces

5. Steps:
   (1)Start the program;
   (2)The program opens the workspace and scene automatically;
   (3)The 3D program is flying.

 
-------------------------------------------------------------------------------------------
*/

using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;
using SuperMap.Desktop;
using System.IO;
using Application = SuperMap.Desktop.Application;
using SuperMap.Data;
using SuperMap.Realspace;
using SuperMap.UI;

namespace SuperMap.Desktop.Samples
{
    public class DesktopPlugin : Plugin
    {
        public DesktopPlugin(PluginInfo pluginInfo)
            : base(pluginInfo)
        {

        }
        private Scene m_currentScene;
        public override Boolean Initialize()
        {
            //register UI loaded event
            Application.ActiveApplication.MainForm.Loaded += new EventHandler(MainForm_Loaded);
            return true;
        }
        void MainForm_Loaded(object sender, EventArgs e)
        {
            try
            {
                //data
                String dataPath = Path.Combine(System.AppDomain.CurrentDomain.BaseDirectory, "../SampleData/3D/CBDDataset/");
                String workspacePath = Path.Combine(dataPath, "CBD.smwu");
                String flyFilePath = Path.Combine(dataPath, "FlyRoutes.fpf");
                String sceneName = "CBD";

                //Open workspace
                WorkspaceConnectionInfo wsInfo = new WorkspaceConnectionInfo(workspacePath);
                if (Application.ActiveApplication.Workspace.Open(wsInfo))
                {
                    //Open scene
                    IFormScene sceneForm = Application.ActiveApplication.CreateSceneWindow();
                    m_currentScene = sceneForm.SceneControl.Scene;
                    m_currentScene.FlyManager.StatusChanged += new StatusChangedEventHandler(FlyManager_StatusChanged);
                    if (m_currentScene.Open(sceneName))
                    {
                        (sceneForm as Form).Text = sceneName;
                        //Open the flight path
                        if (m_currentScene.FlyManager.Routes.FromFile(flyFilePath))
                        {
                            //Display the current window full screen
                            //System.Threading.Thread.Sleep(10000);
                            //Application.ActiveApplication.MainForm.FullScreen = true;
                            //Start flying
                            m_currentScene.FlyManager.Play();
                        }
                    }
                }
            }
            catch (Exception ex)
            {
                Application.ActiveApplication.Output.Output(ex.Message, InfoType.Exception);
                Application.ActiveApplication.Output.Output(ex.StackTrace, InfoType.Exception);
            }
        }

        void FlyManager_StatusChanged(object sender, StatusChangedEventArgs e)
        {
            if (m_currentScene.FlyManager.Status == FlyStatus.Stop)
            {
                Application.ActiveApplication.MainForm.FullScreen = false;
            }
        }

        public override Boolean ExitInstance()
        {
            Application.ActiveApplication.MainForm.Loaded -= new EventHandler(MainForm_Loaded);
            return true;
        }
    }
}
